@@ -1,7 +1,6 @@
 from __future__ import annotations
 
 import functools
-import os
 import typing
 from types import AsyncGeneratorType
 
@@ -108,20 +107,3 @@ def _send_event(
     headers: typing.Mapping[str, str] = None,
 ) -> HttpResponse:
     return SendEventResponse(generator, status, headers)
-
-
-@automatic.register(os.stat_result)
-def _file(
-    stat_result: os.stat_result,
-    filepath: str,
-    download_name: str = None,
-    media_type: str = None,
-    headers: typing.Mapping[str, str] = None,
-) -> HttpResponse:
-    return FileResponse(
-        filepath=filepath,
-        headers=headers,
-        media_type=media_type,
-        download_name=download_name,
-        stat_result=stat_result,
-    )
